@@ -52,6 +52,7 @@ void stripmirc(char *);
 void safequote(char *);
 void oer_debug(int, const char *, ...);
 void secondstostring(time_t, char *, int);
+void sortstring(char *);
 
 #ifndef HAVE_SNPRINTF
 int snprintf(char *, size_t, const char *, ...);
@@ -148,20 +149,24 @@ int oer_doquery(char *function, int level, const char *fmt, ...)
 	va_start(ap, fmt);
 	vsnprintf(stringbuffer, TXT_BUFFER, fmt, ap);
 	va_end(ap);
+#ifdef DEBUG
 	oer_debug(level, "oer_doquery->%s\n", stringbuffer);
+#endif
 	gettimeofday(&tv1, NULL);
 	if(mysql_query(&mystate->mysqldb.mysqldbconn, stringbuffer)) {
+#ifdef DEBUG
 		oer_debug(OER_DEBUG_FATAL, "%s->mysql_query() failed: %s\n", function, mysql_error(&mystate->mysqldb.mysqldbconn));
+#endif
 		return 0;
 	}
 	gettimeofday(&tv2, NULL);
+	snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
 	if(tv2.tv_sec == tv1.tv_sec) {
 		snprintf(stringbuffer, TXT_BUFFER, "%ld usecs", tv2.tv_usec - tv1.tv_usec);
-	} else {
-		/* tv2 > tv1, thats for sure */
-		snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
 	}
+#ifdef DEBUG
 	oer_debug(level, "oer_doquery->mysql_query took %s\n", stringbuffer);
+#endif
 	return 1;
 }
 
@@ -595,3 +600,45 @@ int issamenickandhost(char *n1, char *n2, char *h1, char *h2)
 	return 0;
 }
 
+void sortstring(char *string)
+{
+        int times;
+        int pos;
+        int u1;
+        int u2;
+        int c1;
+        int c2;
+        int c;
+
+	for(times = strlen(string) - 1; times >= 0; times--) {
+                for(pos = strlen(string) - 1; pos > 0; pos--) {
+                        u1 = 0;
+                        u2 = 0;
+                        c1 = string[pos - 1];
+                        c2 = string[pos];
+                        if(isupper(c1)) {
+                                u1 = 1;
+                                c1 = tolower(c1);
+                        }
+                        if(isupper(c2)) {
+                                u2 = 1;
+                                c2 = tolower(c2);
+                        }
+                        if(c1 < c2) {
+                                continue;
+                        }
+                        if(c1 == c2 && u1) {
+                                continue;
+			}
+			if(u1) {
+                                c1 = toupper(c1);
+                        }
+                        if(u2) {
+                                c2 = toupper(c2);
+                        }
+                        c = c2;
+                        string[pos] = c1;
+                        string[pos - 1] = c;
+                }
+        }
+}
