@@ -1,6 +1,7 @@
 #!/bin/sh
 
 CURRDIR=`pwd`
+LOGTO="pre_install.log"
 
 function readln () {
 	echo -n "$1"
@@ -14,6 +15,9 @@ if [ $# -ne 1 ]; then
         exit 1
 fi
 
+rm -f $LOGTO 2>&1 >/dev/null
+touch $LOGTO
+
 echo "Now configuring MySQL for oer+MySQL"
 echo ""
 echo -n "Checking if I can find all the necesarry binaries... "
@@ -49,9 +53,9 @@ if [ "$CREATEDB" = "Y" ]; then
     echo -n "Attempting to connect to $HOST as $USER... "
 
     if [ "$PW" = "" ]; then
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $USER ping 2>&1`
+	$1/mysqladmin -h $HOST -u $USER ping 2>&1 >>$LOGTO
     else
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $USER -p$PW ping 2>&1`
+	$1/mysqladmin -h $HOST -u $USER -p$PW ping 2>&1 >>$LOGTO
     fi
 
     RC=$?
@@ -70,9 +74,9 @@ if [ "$CREATEDB" = "Y" ]; then
     echo -n "Attempting to create database... "
 
     if [ "$PW" = "" ]; then
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $USER create $DB 2>&1`
+	$1/mysqladmin -h $HOST -u $USER create $DB 2>&1 >>$LOGTO
     else
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $USER -p$PW create $DB 2>&1`
+	$1/mysqladmin -h $HOST -u $USER -p$PW create $DB 2>&1 >>$LOGTO
     fi
 
     RC=$?
@@ -104,17 +108,17 @@ if [ "$CREATEDB" = "Y" ]; then
 	if [ "$PW" = "" ]; then
 
 	    if [ "$DBUSERPW" = "" ]; then
-		OUTPUT=`(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER) 2>&1`
+		(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER) 2>&1 >>$LOGTO
 	    else
-		OUTPUT=`(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER) 2>&1`
+		(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER) 2>&1 >>$LOGTO
 	    fi
 
 	else
 
 	    if [ "$DBUSERPW" = "" ]; then
-		OUTPUT=`(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1`
+		(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1 >>$LOGTO
 	    else
-		OUTPUT=`(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1`
+		(echo "GRANT ALL PRIVILEGES ON $DB.* TO $DBUSER@$i IDENTIFIED BY '$DBUSERPW'" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1 >>$LOGTO
 	    fi
 
 	fi
@@ -132,9 +136,9 @@ if [ "$CREATEDB" = "Y" ]; then
     echo -n "Attempting to FLUSH PRIVILEGES... "
 
     if [ "$PW" = "" ]; then
-	OUTPUT=`(echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER) 2>&1`
+	(echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER) 2>&1 >>$LOGTO
     else
-	OUTPUT=`(echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1`
+	(echo "FLUSH PRIVILEGES" | $1/mysql -h $HOST -u $USER -p$PW) 2>&1 >>$LOGTO
     fi
     
     RC=$?
@@ -162,9 +166,9 @@ else
     echo -n "Attempting to connect to $HOST as $DBUSER... "
 
     if [ "$DBUSERPW" = "" ]; then
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $DBUSER ping 2>&1`
+	$1/mysqladmin -h $HOST -u $DBUSER ping 2>&1 >>$LOGTO
     else
-	    OUTPUT=`$1/mysqladmin -h $HOST -u $DBUSER -p$DBUSERPW ping 2>&1`
+	$1/mysqladmin -h $HOST -u $DBUSER -p$DBUSERPW ping 2>&1 >>$LOGTO
     fi
 
     RC=$?
@@ -185,9 +189,9 @@ if [ "$CREATETABLES" = "Y" ]; then
     echo -n "Creating initial tables... "
 
     if [ "$DBUSERPW" = "" ]; then
-	OUTPUT=`($1/mysql -h $HOST -u $DBUSER $DB < $CURRDIR/scripts/initial.sql) 2>&1`
+	($1/mysql -h $HOST -u $DBUSER $DB < $CURRDIR/scripts/initial.sql) 2>&1 >>$LOGTO
     else
-	OUTPUT=`($1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB < $CURRDIR/scripts/initial.sql) 2>&1`
+	($1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB < $CURRDIR/scripts/initial.sql) 2>&1 >>$LOGTO
     fi
     
     RC=$?
@@ -221,7 +225,7 @@ readln "Please specify command prefix [!] " "!"
 PREFIX=$ans
 readln "Please specify IRC REALNAME [http://oer.equnet.org/help.html] " "http://oer.equnet.org/help.html"
 REALNAME=$ans
-readln "Please specify obtional virtual host [] " ""
+readln "Please specify optional virtual host [] " ""
 VIRTHOST=$ans
 readln "Please specify bot handle [oer] " "oer"
 HANDLE=$ans
@@ -248,11 +252,11 @@ readln "Please specify amount of allowed server modes [6] " "6"
 MODES=$ans
 readln "Please specify ping frequency in seconds on $SERVER [90] " "90"
 PINGFREQ=$ans
-readln "Please specify whether IRC operators are protected on $SERVER [1] " "1"
+readln "Please specify whether IRC operators are protected on $SERVER (0 = no, 1 = yes) [0] " "0"
 PROT=$ans
-readln "Please specify whether you want line noise for $SERVER [0] " "0"
+readln "Please specify whether you want line noise for $SERVER (0 = off, >>1 = on) [0] " "0"
 NOISE=$ans
-readln "Please specify obtional server password for $SERVER [] " ""
+readln "Please specify optional server password for $SERVER [] " ""
 SERVERPW=$ans
 
 INSERT_SERVERS="INSERT INTO servers VALUES ('$SERVER','$PORT','$MODES','$PINGFREQ','$PROT','$NOISE','$SERVERPW','$HANDLE')"
@@ -282,9 +286,9 @@ if [ "$IMPORTDATA" = "Y" ]; then
 	esac
 
 	if [ "$DBUSERPW" = "" ]; then
-	    OUTPUT=`(echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER $DB) 2>&1`
+	    (echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER $DB) 2>&1 >>$LOGTO
 	else
-	    OUTPUT=`(echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB) 2>&1`
+	    (echo "$INSERT_COMMAND" | $1/mysql -h $HOST -u $DBUSER -p$DBUSERPW $DB) 2>&1 >>$LOGTO
 	fi
     
 	RC=$?
