@@ -12,8 +12,8 @@ CREATE TABLE admins (
   handle varchar(32) NOT NULL default '',
   flags varchar(32) default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(handle, ident)
-) TYPE=MyISAM;
+  KEY key1(handle,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'adverts'
@@ -24,18 +24,18 @@ CREATE TABLE adverts (
   type varchar(32) NOT NULL default '',
   message text NOT NULL,
   ident varchar(64) NOT NULL default ''
-) TYPE=MyISAM;
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'bantype'
 #
 
 CREATE TABLE bantype (
-  channel varchar(64) default '',
-  type int(11) NOT NULL default '1',
+  channel varchar(64) NOT NULL default '',
+  type tinyint unsigned NOT NULL default '1',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'banvars'
@@ -43,16 +43,16 @@ CREATE TABLE bantype (
 
 CREATE TABLE banvars (
   channel varchar(64) NOT NULL default '',
-  b_auto_rejoin int(11) NOT NULL default '30',
-  b_part_rejoin int(11) NOT NULL default '600',
-  b_flood int(11) NOT NULL default '300',
-  b_flood_repeat int(11) NOT NULL default '600',
-  b_bad_word int(11) NOT NULL default '3600',
-  b_bad_nick int(11) NOT NULL default '3600',
-  b_normal_ban int(11) NOT NULL default '3600',
+  b_auto_rejoin smallint unsigned NOT NULL default '30',
+  b_part_rejoin smallint unsigned NOT NULL default '600',
+  b_flood smallint unsigned NOT NULL default '300',
+  b_flood_repeat smallint unsigned NOT NULL default '600',
+  b_bad_word smallint unsigned NOT NULL default '3600',
+  b_bad_nick smallint unsigned NOT NULL default '3600',
+  b_normal_ban smallint unsigned NOT NULL default '3600',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'channels'
@@ -64,8 +64,8 @@ CREATE TABLE channels (
   chankey varchar(32) default '',
   chanflags varchar(32) default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(name, ident)
-) TYPE=MyISAM;
+  KEY key1(name,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'conf'
@@ -81,24 +81,24 @@ CREATE TABLE conf (
   realname varchar(64) NOT NULL default '',
   vhost varchar(64) default '',
   ident varchar(32) NOT NULL default '',
-  PRIMARY KEY (ident),
+  KEY chanid(ident),
   KEY key1(ident)
-) TYPE=MyISAM;
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'floodvars'
 #
 
 CREATE TABLE floodvars (
-  channel varchar(64) default '',
-  f_expire int(11) NOT NULL default '1800',
-  f_limit int(11) NOT NULL default '3',
-  f_interval int(11) NOT NULL default '60',
-  f_lines int(11) NOT NULL default '10',
-  f_chars int(11) NOT NULL default '1600',
+  channel varchar(64) NOT NULL default '',
+  f_expire smallint unsigned NOT NULL default '1800',
+  f_limit smallint unsigned NOT NULL default '3',
+  f_interval smallint unsigned NOT NULL default '60',
+  f_lines smallint unsigned NOT NULL default '10',
+  f_chars smallint unsigned NOT NULL default '1600',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'hostmasks'
@@ -106,12 +106,12 @@ CREATE TABLE floodvars (
 
 CREATE TABLE hostmasks (
   hostmask varchar(64) NOT NULL default '',
-  channel varchar(64) default '',
-  type int(11) NOT NULL default '0',
+  channel varchar(64) NOT NULL default '',
+  type tinyint unsigned NOT NULL default '0',
   handle varchar(32) NOT NULL default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(hostmask, channel, type, handle, ident)
-) TYPE=MyISAM;
+  KEY key1(hostmask,channel,type,handle,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'kickreasons'
@@ -119,8 +119,8 @@ CREATE TABLE hostmasks (
 
 CREATE TABLE kickreasons (
   reason varchar(255) NOT NULL default '',
-  ident varchar(4) NOT NULL default ''
-) TYPE=MyISAM;
+  ident varchar(64) NOT NULL default ''
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'nickbks'
@@ -131,20 +131,20 @@ CREATE TABLE nickbks (
   pattern varchar(32) NOT NULL default '',
   reason varchar(64) default '',
   setby varchar(32) default '',
-  twhen int(10) unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, pattern, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,pattern,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'output'
 #
 
 CREATE TABLE output (
-  twhen int(10) unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   ident varchar(64) NOT NULL default '',
   message text NOT NULL
-) TYPE=MyISAM;
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'passwords'
@@ -153,11 +153,11 @@ CREATE TABLE output (
 CREATE TABLE passwords (
   handle varchar(32) NOT NULL default '',
   channel varchar(64) NOT NULL default '',
-  type int(11) NOT NULL default '0',
+  type tinyint unsigned NOT NULL default '0',
   password varchar(32) NOT NULL default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(handle, channel, type, ident)
-) TYPE=MyISAM;
+  KEY key1(handle,channel,type,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'permbans'
@@ -168,20 +168,20 @@ CREATE TABLE permbans (
   mask varchar(64) NOT NULL default '',
   reason varchar(64) default '',
   setby varchar(32) default '',
-  twhen int(10) unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, mask, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,mask,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'raw'
 #
 
 CREATE TABLE raw (
-  twhen int(10) unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   ident varchar(64) NOT NULL default '',
   message text NOT NULL
-) TYPE=MyISAM;
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'servers'
@@ -189,15 +189,25 @@ CREATE TABLE raw (
 
 CREATE TABLE servers (
   hostname varchar(64) NOT NULL default '',
-  port int(11) NOT NULL default '6667',
-  servermodes tinyint(4) NOT NULL default '4',
-  pingfreq smallint(6) NOT NULL default '90',
-  protopers tinyint(4) NOT NULL default '0',
-  linenoise tinyint(4) NOT NULL default '0',
+  port smallint unsigned NOT NULL default '6667',
+  servermodes tinyint unsigned NOT NULL default '4',
+  pingfreq tinyint unsigned NOT NULL default '90',
+  protopers tinyint unsigned NOT NULL default '0',
+  linenoise tinyint unsigned NOT NULL default '0',
   password varchar(32) default '',
   ident varchar(32) NOT NULL default '',
-  KEY key1(hostname, port, servermodes, pingfreq, protopers, linenoise, ident)
-) TYPE=MyISAM;
+  KEY key1(hostname,port,servermodes,pingfreq,protopers,linenoise,ident)
+) TYPE=MyISAM PACK_KEYS=1;
+
+#
+# Table structure for table 'services'
+#
+
+CREATE TABLE services (
+  host varchar(64) NOT NULL default '',
+  ident varchar(64) NOT NULL default '',
+  KEY key1(host,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'timestamps'
@@ -205,11 +215,11 @@ CREATE TABLE servers (
 
 CREATE TABLE timestamps (
   ttype varchar(32) NOT NULL default '',
-  twhen int(10) unsigned NOT NULL default '0',
-  tchannel varchar(32) NOT NULL default '',
+  twhen int unsigned NOT NULL default '0',
+  tchannel varchar(64) NOT NULL default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(ttype, tchannel, ident)
-) TYPE=MyISAM;
+  KEY key1(ttype,tchannel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'topics'
@@ -217,13 +227,13 @@ CREATE TABLE timestamps (
 
 CREATE TABLE topics (
   channel varchar(64) NOT NULL default '',
-  pos int(10) unsigned NOT NULL default '0',
-  twhen int(10) unsigned NOT NULL default '0',
+  pos tinyint unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   setby varchar(32) NOT NULL default '',
   message varchar(255) NOT NULL default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, pos, ident)
-) TYPE=MyISAM;
+  KEY key1(channel,pos,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'trusted'
@@ -232,8 +242,8 @@ CREATE TABLE topics (
 CREATE TABLE trusted (
   host varchar(64) NOT NULL default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(host, ident)
-) TYPE=MyISAM;
+  KEY key1(host,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'users'
@@ -241,11 +251,11 @@ CREATE TABLE trusted (
 
 CREATE TABLE users (
   handle varchar(32) NOT NULL default '',
-  channel varchar(64) default '',
+  channel varchar(64) NOT NULL default '',
   flags varchar(32) default '',
   ident varchar(64) NOT NULL default '',
-  KEY key1(handle, channel, ident)
-) TYPE=MyISAM;
+  KEY key1(handle,channel,ident)
+) TYPE=MyISAM PACK_KEYS=1;
 
 #
 # Table structure for table 'wordbks'
@@ -256,10 +266,7 @@ CREATE TABLE wordbks (
   pattern varchar(32) NOT NULL default '',
   reason varchar(64) default '',
   setby varchar(32) default '',
-  twhen int(10) unsigned NOT NULL default '0',
+  twhen int unsigned NOT NULL default '0',
   ident varchar(64) NOT NULL default '',
-  KEY key1(channel, pattern, ident)
-) TYPE=MyISAM;
-
-
-
+  KEY key1(channel,pattern,ident)
+) TYPE=MyISAM PACK_KEYS=1;
